@@ -20,14 +20,13 @@ bl_info = {
     "name": "Curve Tools",
     "author": "Zak",
     "version": (0, 1, 5),
-    "blender": (2, 5, 9),
+    "blender": (2, 59, 0),
     "location": "Properties > Object data",
     "description": "Creates driven Lofts or Birails between curves",
     "warning": "may be buggy or incomplete",
-    "wiki_url": "http://wiki.blender.org/index.php/Extensions:2.6/Py/"\
+    "wiki_url": "http://wiki.blender.org/index.php/Extensions:2.6/Py/"
         "Scripts/Curve/Curve_Tools",
-    "tracker_url": "https://projects.blender.org/tracker/index.php?"\
-        "func=detail&aid=27720",
+    "tracker_url": "https://developer.blender.org/T27720",
     "category": "Add Curve"}
 
 ### UPDATES
@@ -696,10 +695,10 @@ def birail1(objs, steps, spans, proportional):
 
         #if angle1!=0.0 and angle2!=0: we can avoid some operations by doing this check but im lazy
         cr1 = der1.cross(der10)
-        rot1 = Matrix().Rotation(-angle1, 3, cr1)
+        rot1 = Matrix.Rotation(-angle1, 3, cr1)
 
         cr2 = der2.cross(der20)
-        rot2 = Matrix().Rotation(-angle2, 3, cr2)
+        rot2 = Matrix.Rotation(-angle2, 3, cr2)
 
         if proportional:
             mult = rmag/r0mag
