@@ -19,13 +19,15 @@
 bl_info = {
     "name": "LipSync Importer & Blinker",
     "author": "Yousef Harfoush - bat3a ;)",
-    "version": (0, 5, 0),
-    "blender": (2, 6, 2),
+    "version": (0, 5, 1),
+    "blender": (2, 70, 0),
     "location": "3D window > Tool Shelf",
-    "description": "Plot Moho (Papagayo, Jlipsync, Yolo) file to frames and adds automatic blinking",
+    "description": "Plots Moho (Papagayo, Jlipsync, Yolo) file "
+        "to frames and adds automatic blinking",
     "warning": "",
-    "wiki_url": "http://wiki.blender.org/index.php?title=Extensions:2.6/Py/Scripts/Import-Export/Lipsync Importer",
-    "tracker_url": "http://projects.blender.org/tracker/index.php?func=detail&aid=24080&group_id=153&atid=468",
+    "wiki_url": "http://wiki.blender.org/index.php?title=Extensions:2.6/Py/"
+        "Scripts/Import-Export/Lipsync Importer",
+    "tracker_url": "https://developer.blender.org/T24080",
     "category": "Import-Export"}
 
 
@@ -37,13 +39,9 @@ from bpy.props import IntProperty, FloatProperty, StringProperty
 global lastPhoneme
 lastPhoneme="nothing"
 
-# truning off relative path - it causes an error if it was true
-if bpy.context.user_preferences.filepaths.use_relative_paths == True:
-    bpy.context.user_preferences.filepaths.use_relative_paths = False
-
 # add blinking
 def blinker():
-    
+
     scn = bpy.context.scene
     obj = bpy.context.object
 
@@ -51,7 +49,7 @@ def blinker():
         modifier = 0
     elif scn.regMenuTypes.enumBlinkTypes == '1':
         modifier = scn.blinkMod
-    
+
     #creating keys with blinkNm count
     for y in range(scn.blinkNm):
         frame = y * scn.blinkSp + int(random()*modifier)
@@ -77,20 +75,20 @@ def lipsyncerBone():
     object = bpy.context.object
     scene = bpy.context.scene
     bone = bpy.context.active_pose_bone
-    
+
     resetBoneScale(bone)
-    
+
     f=open(scene.fpath) # importing file
     f.readline() # reading the 1st line that we don"t need
-    
+
     for line in f:
         # removing new lines
         lsta = re.split("\n+", line)
 
         # building a list of frames & shapes indexes
-        lst = re.split(":? ", lsta[0])# making a list of a frame & number 
+        lst = re.split(":? ", lsta[0])# making a list of a frame & number
         frame = int(lst[0])
-        
+
         for key,attribute in bone_keys.items():
             if lst[1] == key:
                 createBoneKeys(key, bone, attribute, frame)
@@ -104,11 +102,11 @@ def resetBoneScale(bone):
         else:
             exec("bone.%s = %f" % (attribute, 0.0))
 
-def addBoneKey(bone, data_path, index=-1, value=None, frame=bpy.context.scene.frame_current, group=""):
+def addBoneKey(bone, data_path, index=-1, value=None, frame=0, group=""):
     # set a value and keyframe for the bone
     # it assumes the 'bone' variable was defined before
     # and it's the current selected bone
-
+    frame=bpy.context.scene.frame_current
     if value != None:
         if index != -1:
             # bone.location[0] = 0.0
@@ -122,19 +120,19 @@ def addBoneKey(bone, data_path, index=-1, value=None, frame=bpy.context.scene.fr
 # creating keys with offset and eases for a phonem @ the Skframe
 def createBoneKeys(phoneme, bone, attribute, frame):
     global lastPhoneme
-    
+
     scene = bpy.context.scene
     object = bpy.context.object
-    
+
     offst = scene.offset     # offset value
     skVlu = scene.skscale    # shape key value
-    
+
     #in case of Papagayo format
     if scene.regMenuTypes.enumFileTypes == '0' :
         frmIn = scene.easeIn     # ease in value
         frmOut = scene.easeOut   # ease out value
         hldIn = scene.holdGap    # holding time value
-        
+
     #in case of Jlipsync format or Yolo
     elif scene.regMenuTypes.enumFileTypes == '1' :
         frmIn = 1
@@ -148,51 +146,51 @@ def createBoneKeys(phoneme, bone, attribute, frame):
     addBoneKey(bone, attribute[0], attribute[1], skVlu, offst+frame, "Lipsync")
     addBoneKey(bone, attribute[0], attribute[1], skVlu, offst+frame+hldIn, "Lipsync")
     addBoneKey(bone, attribute[0], attribute[1], 0.0, offst+frame+hldIn+frmOut, "Lipsync")
-    
+
     lastPhoneme=phoneme
 
 # -------------------------------------------------------------------------------
 
 # reading imported file & creating keys
 def lipsyncer():
-    
+
     obj = bpy.context.object
     scn = bpy.context.scene
-    
+
     f=open(scn.fpath) # importing file
     f.readline() # reading the 1st line that we don"t need
-    
+
     for line in f:
 
         # removing new lines
         lsta = re.split("\n+", line)
 
         # building a list of frames & shapes indexes
-        lst = re.split(":? ", lsta[0])# making a list of a frame & number 
+        lst = re.split(":? ", lsta[0])# making a list of a frame & number
         frame = int(lst[0])
-        
+
         for key in obj.data.shape_keys.key_blocks:
             if lst[1] == key.name:
                 createShapekey(key.name, frame)
 
 # creating keys with offset and eases for a phonem @ the frame
 def createShapekey(phoneme, frame):
-    
+
     global lastPhoneme
-    
+
     scn = bpy.context.scene
     obj = bpy.context.object
     objSK = obj.data.shape_keys
-    
+
     offst = scn.offset     # offset value
     skVlu = scn.skscale    # shape key value
-    
+
     #in case of Papagayo format
     if scn.regMenuTypes.enumFileTypes == '0' :
         frmIn = scn.easeIn     # ease in value
         frmOut = scn.easeOut   # ease out value
         hldIn = scn.holdGap    # holding time value
-        
+
     #in case of Jlipsync format or Yolo
     elif scn.regMenuTypes.enumFileTypes == '1' :
         frmIn = 1
@@ -204,19 +202,19 @@ def createShapekey(phoneme, frame):
         objSK.key_blocks[phoneme].value=0.0
         objSK.key_blocks[phoneme].keyframe_insert("value",
             -1, offst+frame-frmIn, "Lipsync")
-            
+
     objSK.key_blocks[phoneme].value=skVlu
-    objSK.key_blocks[phoneme].keyframe_insert("value", 
+    objSK.key_blocks[phoneme].keyframe_insert("value",
         -1, offst+frame, "Lipsync")
-    
+
     objSK.key_blocks[phoneme].value=skVlu
-    objSK.key_blocks[phoneme].keyframe_insert("value", 
+    objSK.key_blocks[phoneme].keyframe_insert("value",
         -1, offst+frame+hldIn, "Lipsync")
-            
+
     objSK.key_blocks[phoneme].value=0.0
-    objSK.key_blocks[phoneme].keyframe_insert("value", 
+    objSK.key_blocks[phoneme].keyframe_insert("value",
     -1, offst+frame+hldIn+frmOut, "Lipsync")
-    
+
     lastPhoneme = phoneme
 
 # lipsyncer operation start
@@ -237,13 +235,13 @@ class btn_lipsyncer(bpy.types.Operator):
                     if scn.fpath!='': lipsyncer()
                     else: print ("select a Moho file")
                 else: print("No shape keys")
-    
+
             elif obj.type=="ARMATURE":
                 if 1:#XXX add prop test
                     if scn.fpath!='': lipsyncerBone()
                     else: print ("select a Moho file")
                 else: print("Create Pose properties")
-                
+
             else: print ("Object is not a mesh ot bone")
         else: print ("Select object")
         return {'FINISHED'}
@@ -255,7 +253,7 @@ class btn_blinker(bpy.types.Operator):
     bl_description = 'Add blinks at random or specifice frames'
 
     def execute(self, context):
-        
+
         scn = context.scene
         obj = context.object
 
@@ -276,7 +274,7 @@ class btn_blinker(bpy.types.Operator):
 #defining custom enumeratos
 class menuTypes(bpy.types.PropertyGroup):
 
-    enumFileTypes = EnumProperty(items =(('0', 'Papagayo', ''), 
+    enumFileTypes = EnumProperty(items =(('0', 'Papagayo', ''),
                                          ('1', 'Jlipsync Or Yolo', '')
                                        #,('2', 'Retarget', '')
                                          ),
@@ -292,19 +290,20 @@ class menuTypes(bpy.types.PropertyGroup):
                                          ('1', 'Blinker','')),
                                  name = 'Choose Mode',
                                  default = '0')
-                                 
+
 # drawing the user interface
 class LipSyncBoneUI(bpy.types.Panel):
     bl_space_type = "VIEW_3D"
     bl_region_type = "UI"
     bl_label = "Phonemes"
+    bl_category = 'Animation'
     
     def draw(self, context):
         layout = self.layout
         col = layout.column()
 
         bone = bpy.context.active_pose_bone
-        
+
         #showing the current object type
         if bone: #and if scn.regMenuTypes.enumModeTypes == '0':
             col.prop(bone, "location", index=0, text="AI")
@@ -329,16 +328,15 @@ class LipSyncBoneUI(bpy.types.Panel):
             col.prop(bone, "scale", index=2, text="etc")
         else:
             layout.label(text="No good bone is selected")
-            
+
 # drawing the user interface
 class LipSyncUI(bpy.types.Panel):
     bl_space_type = "VIEW_3D"
     bl_region_type = "TOOL_PROPS"
     bl_label = "LipSync Importer & Blinker"
-    
+
     newType= bpy.types.Scene
-    scn = bpy.context.scene
-    
+
     newType.fpath = StringProperty(name="Import File ", description="Select your voice file", subtype="FILE_PATH")
     newType.skscale = FloatProperty(description="Smoothing shape key values", min=0.1, max=1.0, default=0.8)
     newType.offset = IntProperty(description="Offset your frames", default=0)
@@ -349,14 +347,14 @@ class LipSyncUI(bpy.types.Panel):
 
     newType.blinkSp = IntProperty(description="Space between blinks", min=1, default=100)
     newType.blinkNm = IntProperty(description="Number of blinks", min=1, default=10)
-    
+
     newType.blinkMod = IntProperty(description="Randomzing keyframe placment", min=1, default=10)
-    
+
     def draw(self, context):
-        
+
         obj = bpy.context.active_object
         scn = bpy.context.scene
-        
+
         layout = self.layout
         col = layout.column()
 
@@ -377,15 +375,15 @@ class LipSyncUI(bpy.types.Panel):
                 col.label(text="The active object is not a Mesh or Armature!", icon="OBJECT_DATA")
         else:
             layout.label(text="No object is selected", icon="OBJECT_DATA")
-            
+
         col.row().prop(scn.regMenuTypes, 'enumModeTypes')
         col.separator()
-        
-        # the lipsyncer panel 
+
+        # the lipsyncer panel
         if scn.regMenuTypes.enumModeTypes == '0':
             # choose the file format
             col.row().prop(scn.regMenuTypes, 'enumFileTypes', text = ' ', expand = True)
-                
+
             # Papagayo panel
             if scn.regMenuTypes.enumFileTypes == '0':
                 col.prop(context.scene, "fpath")
@@ -399,7 +397,7 @@ class LipSyncUI(bpy.types.Panel):
                 split.prop(context.scene, "easeIn", "Ease In")
                 split.prop(context.scene, "holdGap", "Hold Gap")
                 split.prop(context.scene, "easeOut", "Ease Out")
-                
+
                 col.operator('lipsync.go', text='Plot Keys to the Timeline')
 
             # Jlipsync & Yolo panel
@@ -411,14 +409,14 @@ class LipSyncUI(bpy.types.Panel):
                 split = col.split(align=True)
                 split.label("Frame Offset :")
                 split.prop(context.scene, "offset")
-                
+
                 col.operator('lipsync.go', text='Plot Keys to the Timeline')
-        
+
         # the blinker panel
         elif scn.regMenuTypes.enumModeTypes == '1':
             # choose blink type
             col.row().prop(scn.regMenuTypes, 'enumBlinkTypes', text = ' ', expand = True)
-            
+
             # specific panel
             if scn.regMenuTypes.enumBlinkTypes == '0':
                 split = col.split(align=True)
@@ -434,7 +432,7 @@ class LipSyncUI(bpy.types.Panel):
                 col.prop(context.scene, "blinkSp", "Spacing")
                 col.prop(context.scene, "blinkNm", "Times")
                 col.operator('blink.go', text='Add Keys to the Timeline')
-            
+
             # Random panel
             elif scn.regMenuTypes.enumBlinkTypes == '1':
                 split = col.split(align=True)
@@ -452,15 +450,15 @@ class LipSyncUI(bpy.types.Panel):
                 split.prop(context.scene, "blinkMod", "Random Modifier")
                 col.prop(context.scene, "blinkNm", "Times")
                 col.operator('blink.go', text='Add Keys to the Timeline')
-        
-        
+
+
 # clearing vars
 def clear_properties():
 
     # can happen on reload
     if bpy.context.scene is None:
         return
-     
+
     props = ["fpath", "skscale", "offset", "easeIn", "easeOut", "holdGap", "blinkSp", "blinkNm", "blinkMod"]
     for p in props:
         if p in bpy.types.Scene.bl_rna.properties:
