@@ -18,19 +18,20 @@
 
 # <pep8 compliant>
 import bpy
-from bpy.types import Menu, Panel
+from bpy.types import Menu, Panel, UIList
 
 from bpy.types import (Brush,
                        Lamp,
                        Material,
                        Object,
                        ParticleSettings,
+                       FreestyleLineStyle,
                        Texture,
                        World)
 
 from rna_prop_ui import PropertyPanel
 
-from bl_ui.properties_paint_common import sculpt_brush_texture_settings
+from bl_ui.properties_paint_common import brush_texture_settings
 
 
 class TEXTURE_MT_specials(Menu):
@@ -55,6 +56,25 @@ class TEXTURE_MT_envmap_specials(Menu):
         layout.operator("texture.envmap_clear", icon='FILE_REFRESH')
         layout.operator("texture.envmap_clear_all", icon='FILE_REFRESH')
 
+
+class TEXTURE_UL_texslots(UIList):
+    def draw_item(self, context, layout, data, item, icon, active_data, active_propname, index):
+        # assert(isinstance(item, bpy.types.MaterialTextureSlot)
+        ma = data
+        slot = item
+        tex = slot.texture if slot else None
+        if self.layout_type in {'DEFAULT', 'COMPACT'}:
+            if tex:
+                layout.prop(tex, "name", text="", emboss=False, icon_value=icon)
+            else:
+                layout.label(text="", icon_value=icon)
+            if tex and isinstance(item, bpy.types.MaterialTextureSlot):
+                layout.prop(ma, "use_textures", text="", index=index)
+        elif self.layout_type in {'GRID'}:
+            layout.alignment = 'CENTER'
+            layout.label(text="", icon_value=icon)
+
+
 from bl_ui.properties_material import active_node_mat
 
 
@@ -75,6 +95,10 @@ def context_tex_datablock(context):
     if idblock:
         return idblock
 
+    idblock = context.line_style
+    if idblock:
+        return idblock
+
     if context.particle_system:
         idblock = context.particle_system.settings
 
@@ -109,15 +133,16 @@ class TEXTURE_PT_context_texture(TextureButtonsPanel, Panel):
     @classmethod
     def poll(cls, context):
         engine = context.scene.render.engine
-        if not (hasattr(context, "texture_slot") or hasattr(context, "texture_node")):
-            return False
+        #if not (hasattr(context, "texture_slot") or hasattr(context, "texture_node")):
+            #return False
         return ((context.material or
                  context.world or
                  context.lamp or
-                 context.brush or
                  context.texture or
+                 context.line_style or
                  context.particle_system or
-                 isinstance(context.space_data.pin_id, ParticleSettings)) and
+                 isinstance(context.space_data.pin_id, ParticleSettings) or
+                 context.texture_user) and
                 (engine in cls.COMPAT_ENGINES))
 
     def draw(self, context):
@@ -130,49 +155,71 @@ class TEXTURE_PT_context_texture(TextureButtonsPanel, Panel):
         idblock = context_tex_datablock(context)
         pin_id = space.pin_id
 
+        space.use_limited_texture_context = True
+
         if space.use_pin_id and not isinstance(pin_id, Texture):
             idblock = id_tex_datablock(pin_id)
             pin_id = None
 
         if not space.use_pin_id:
             layout.prop(space, "texture_context", expand=True)
+            pin_id = None
+
+        if space.texture_context == 'OTHER':
+            if not pin_id:
+                layout.template_texture_user()
+            user = context.texture_user
+            if user or pin_id:
+                layout.separator()
+
+                split = layout.split(percentage=0.65)
+                col = split.column()
+
+                if pin_id:
+                    col.template_ID(space, "pin_id")
+                else:
+                    propname = context.texture_user_property.identifier
+                    col.template_ID(user, propname, new="texture.new")
+
+                if tex:
+                    split = layout.split(percentage=0.2)
+                    if tex.use_nodes:
+                        if slot:
+                            split.label(text="Output:")
+                            split.prop(slot, "output_node", text="")
+                    else:
+                        split.label(text="Type:")
+                        split.prop(tex, "type", text="")
+            return
 
         tex_collection = (pin_id is None) and (node is None) and (not isinstance(idblock, Brush))
 
         if tex_collection:
             row = layout.row()
 
-            row.template_list(idblock, "texture_slots", idblock, "active_texture_index", rows=2)
+            row.template_list("TEXTURE_UL_texslots", "", idblock, "texture_slots", idblock, "active_texture_index", rows=2)
 
             col = row.column(align=True)
             col.operator("texture.slot_move", text="", icon='TRIA_UP').type = 'UP'
             col.operator("texture.slot_move", text="", icon='TRIA_DOWN').type = 'DOWN'
             col.menu("TEXTURE_MT_specials", icon='DOWNARROW_HLT', text="")
 
-        split = layout.split(percentage=0.65)
-        col = split.column()
-
         if tex_collection:
-            col.template_ID(idblock, "active_texture", new="texture.new")
+            layout.template_ID(idblock, "active_texture", new="texture.new")
         elif node:
-            col.template_ID(node, "texture", new="texture.new")
+            layout.template_ID(node, "texture", new="texture.new")
         elif idblock:
-            col.template_ID(idblock, "texture", new="texture.new")
+            layout.template_ID(idblock, "texture", new="texture.new")
 
         if pin_id:
-            col.template_ID(space, "pin_id")
-
-        col = split.column()
+            layout.template_ID(space, "pin_id")
 
         if tex:
             split = layout.split(percentage=0.2)
-
             if tex.use_nodes:
-
                 if slot:
                     split.label(text="Output:")
                     split.prop(slot, "output_node", text="")
-
             else:
                 split.label(text="Type:")
                 split.prop(tex, "type", text="")
@@ -180,7 +227,7 @@ class TEXTURE_PT_context_texture(TextureButtonsPanel, Panel):
 
 class TEXTURE_PT_preview(TextureButtonsPanel, Panel):
     bl_label = "Preview"
-    COMPAT_ENGINES = {'BLENDER_RENDER', 'BLENDER_GAME'}
+    COMPAT_ENGINES = {'BLENDER_RENDER', 'BLENDER_GAME', 'CYCLES'}
 
     def draw(self, context):
         layout = self.layout
@@ -228,6 +275,9 @@ class TEXTURE_PT_colors(TextureButtonsPanel, Panel):
         col.prop(tex, "contrast")
         col.prop(tex, "saturation")
 
+        col = layout.column()
+        col.prop(tex, "use_clamp", text="Clamp")
+
 # Texture Slot Panels #
 
 
@@ -421,6 +471,12 @@ class TEXTURE_PT_image_sampling(TextureTypePanel, Panel):
     COMPAT_ENGINES = {'BLENDER_RENDER', 'BLENDER_GAME'}
 
     def draw(self, context):
+        if context.scene.render.engine == 'BLENDER_GAME':
+            self.draw_bge(context)
+        else:
+            self.draw_bi(context)
+
+    def draw_bi(self, context):
         layout = self.layout
 
         idblock = context_tex_datablock(context)
@@ -431,7 +487,9 @@ class TEXTURE_PT_image_sampling(TextureTypePanel, Panel):
 
         col = split.column()
         col.label(text="Alpha:")
-        col.prop(tex, "use_alpha", text="Use")
+        row = col.row()
+        row.active = bool(tex.image and tex.image.use_alpha)
+        row.prop(tex, "use_alpha", text="Use")
         col.prop(tex, "use_calculate_alpha", text="Calculate")
         col.prop(tex, "invert_alpha", text="Invert")
         col.separator()
@@ -458,6 +516,33 @@ class TEXTURE_PT_image_sampling(TextureTypePanel, Panel):
 
         texture_filter_common(tex, col)
 
+    def draw_bge(self, context):
+        layout = self.layout
+
+        idblock = context_tex_datablock(context)
+        tex = context.texture
+        slot = getattr(context, "texture_slot", None)
+
+        split = layout.split()
+
+        col = split.column()
+        col.label(text="Alpha:")
+        col.prop(tex, "use_calculate_alpha", text="Calculate")
+        col.prop(tex, "invert_alpha", text="Invert")
+
+        col = split.column()
+
+        #Only for Material based textures, not for Lamp/World...
+        if slot and isinstance(idblock, Material):
+            col.prop(tex, "use_normal_map")
+            row = col.row()
+            row.active = tex.use_normal_map
+            row.prop(slot, "normal_map_space", text="")
+
+            row = col.row()
+            row.active = not tex.use_normal_map
+            row.prop(tex, "use_derivative_map")
+
 
 class TEXTURE_PT_image_mapping(TextureTypePanel, Panel):
     bl_label = "Image Mapping"
@@ -482,17 +567,17 @@ class TEXTURE_PT_image_mapping(TextureTypePanel, Panel):
 
             col = split.column(align=True)
             col.label(text="Mirror:")
-            row = col.row()
+            row = col.row(align=True)
             row.prop(tex, "use_mirror_x", text="X")
             row.active = (tex.repeat_x > 1)
-            row = col.row()
+            row = col.row(align=True)
             row.prop(tex, "use_mirror_y", text="Y")
             row.active = (tex.repeat_y > 1)
             layout.separator()
 
         elif tex.extension == 'CHECKER':
             col = split.column(align=True)
-            row = col.row()
+            row = col.row(align=True)
             row.prop(tex, "use_checker_even", text="Even")
             row.prop(tex, "use_checker_odd", text="Odd")
 
@@ -873,11 +958,28 @@ class TEXTURE_PT_mapping(TextureSlotPanel, Panel):
                 split.label(text="Object:")
                 split.prop(tex, "object", text="")
 
+            elif tex.texture_coords == 'ALONG_STROKE':
+                split = layout.split(percentage=0.3)
+                split.label(text="Use Tips:")
+                split.prop(tex, "use_tips", text="")
+
         if isinstance(idblock, Brush):
-            if context.sculpt_object:
-                sculpt_brush_texture_settings(layout, idblock)
+            if context.sculpt_object or context.image_paint_object:
+                brush_texture_settings(layout, idblock, context.sculpt_object)
         else:
-            if isinstance(idblock, Material):
+            if isinstance(idblock, FreestyleLineStyle):
+                split = layout.split(percentage=0.3)
+                split.label(text="Projection:")
+                split.prop(tex, "mapping", text="")
+
+                split = layout.split(percentage=0.3)
+                split.separator()
+                row = split.row()
+                row.prop(tex, "mapping_x", text="")
+                row.prop(tex, "mapping_y", text="")
+                row.prop(tex, "mapping_z", text="")
+
+            elif isinstance(idblock, Material):
                 split = layout.split(percentage=0.3)
                 split.label(text="Projection:")
                 split.prop(tex, "mapping", text="")
@@ -887,8 +989,12 @@ class TEXTURE_PT_mapping(TextureSlotPanel, Panel):
                 col = split.column()
                 if tex.texture_coords in {'ORCO', 'UV'}:
                     col.prop(tex, "use_from_dupli")
+                    if (idblock.type == 'VOLUME' and tex.texture_coords == 'ORCO'):
+                        col.prop(tex, "use_map_to_bounds")
                 elif tex.texture_coords == 'OBJECT':
                     col.prop(tex, "use_from_original")
+                    if (idblock.type == 'VOLUME'):
+                        col.prop(tex, "use_map_to_bounds")
                 else:
                     col.label()
 
@@ -930,7 +1036,7 @@ class TEXTURE_PT_influence(TextureSlotPanel, Panel):
         def factor_but(layout, toggle, factor, name):
             row = layout.row(align=True)
             row.prop(tex, toggle, text="")
-            sub = row.row()
+            sub = row.row(align=True)
             sub.active = getattr(tex, toggle)
             sub.prop(tex, factor, text=name, slider=True)
             return sub  # XXX, temp. use_map_normal needs to override.
@@ -984,6 +1090,8 @@ class TEXTURE_PT_influence(TextureSlotPanel, Panel):
                 factor_but(col, "use_map_hardness", "hardness_factor", "Hardness")
                 factor_but(col, "use_map_translucency", "translucency_factor", "Add")
             elif idblock.type == 'VOLUME':
+                layout.label(text="Volume:")
+
                 split = layout.split()
 
                 col = split.column()
@@ -998,6 +1106,16 @@ class TEXTURE_PT_influence(TextureSlotPanel, Panel):
                 factor_but(col, "use_map_color_transmission", "transmission_color_factor", "Transmission Color")
                 factor_but(col, "use_map_color_reflection", "reflection_color_factor", "Reflection Color")
 
+                layout.label(text="Geometry:")
+
+                split = layout.split()
+
+                col = split.column()
+                factor_but(col, "use_map_warp", "warp_factor", "Warp")
+
+                col = split.column()
+                factor_but(col, "use_map_displacement", "displacement_factor", "Displace")
+
         elif isinstance(idblock, Lamp):
             split = layout.split()
 
@@ -1046,6 +1164,15 @@ class TEXTURE_PT_influence(TextureSlotPanel, Panel):
             factor_but(col, "use_map_kink", "kink_factor", "Kink")
             factor_but(col, "use_map_rough", "rough_factor", "Rough")
 
+        elif isinstance(idblock, FreestyleLineStyle):
+            split = layout.split()
+
+            col = split.column()
+            factor_but(col, "use_map_color_diffuse", "diffuse_color_factor", "Color")
+            col = split.column()
+            factor_but(col, "use_map_alpha", "alpha_factor", "Alpha")
+
+
         layout.separator()
 
         if not isinstance(idblock, ParticleSettings):
